@@ -12,6 +12,7 @@ from yarl import URL
 
 import aiohttp
 from aiohttp.client_reqrep import ClientRequest, ClientResponse
+from aiohttp.connector import _SSL_CONTEXT_VERIFIED
 from aiohttp.helpers import TimerNoop
 from aiohttp.test_utils import make_mocked_coro
 
@@ -817,7 +818,7 @@ class TestProxy(unittest.TestCase):
         self.loop.start_tls.assert_called_with(
             mock.ANY,
             mock.ANY,
-            self.loop.run_until_complete(connector._make_or_get_ssl_context(True)),
+            _SSL_CONTEXT_VERIFIED,
             server_hostname="www.python.org",
             ssl_handshake_timeout=mock.ANY,
         )
